==> jc-1.4.0.tar.gz: java/nio/channels/ClosedByInterruptException.h <==
// public class java.nio.channels.ClosedByInterruptException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 3b88087022cf5b94 java_nio_channels_AsynchronousCloseException
// @dep_class 4a6ca7edb3c4d226 java_nio_channels_ClosedByInterruptException
// @dep_class 389bd38d1c277676 java_nio_channels_ClosedChannelException

// header file dependencies
// @dep_header java_nio_channels_AsynchronousCloseException

#include "java/nio/channels/AsynchronousCloseException.h"

#ifndef _JC_java_nio_channels_ClosedByInterruptException_H_
#define _JC_java_nio_channels_ClosedByInterruptException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_nio_channels_ClosedByInterruptException$sub_refs	_jc_java_nio_channels_ClosedByInterruptException$sub_refs;
typedef struct _jc_java_nio_channels_ClosedByInterruptException$sub_nonrefs	_jc_java_nio_channels_ClosedByInterruptException$sub_nonrefs;
typedef struct _jc_java_nio_channels_ClosedByInterruptException$refs	_jc_java_nio_channels_ClosedByInterruptException$refs;
typedef struct _jc_java_nio_channels_ClosedByInterruptException$nonrefs	_jc_java_nio_channels_ClosedByInterruptException$nonrefs;
typedef struct _jc_java_nio_channels_ClosedByInterruptException$object	_jc_java_nio_channels_ClosedByInterruptException$object;

typedef const struct _jc_java_nio_channels_ClosedByInterruptException$vmethods	_jc_java_nio_channels_ClosedByInterruptException$vmethods;
typedef const struct _jc_java_nio_channels_ClosedByInterruptException$vtable	_jc_java_nio_channels_ClosedByInterruptException$vtable;
typedef const struct _jc_java_nio_channels_ClosedByInterruptException$vtype	_jc_java_nio_channels_ClosedByInterruptException$vtype;

// Constructors
extern void _jc_java_nio_channels_ClosedByInterruptException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_channels_ClosedByInterruptException$object *);

// Virtual methods structure
struct _jc_java_nio_channels_ClosedByInterruptException$vmethods {
};

// Vtable
struct _jc_java_nio_channels_ClosedByInterruptException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_nio_channels_ClosedChannelException$vmethods	java_nio_channels_ClosedChannelException;
	_jc_java_nio_channels_AsynchronousCloseException$vmethods	java_nio_channels_AsynchronousCloseException;
	_jc_java_nio_channels_ClosedByInterruptException$vmethods	java_nio_channels_ClosedByInterruptException;
};

// Vtype
struct _jc_java_nio_channels_ClosedByInterruptException$vtype {
	_jc_type			type;
	_jc_java_nio_channels_ClosedByInterruptException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_channels_ClosedByInterruptException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_channels_ClosedByInterruptException$refs {
    _jc_java_nio_channels_ClosedByInterruptException$sub_refs	java_nio_channels_ClosedByInterruptException;
    _jc_java_nio_channels_AsynchronousCloseException$sub_refs	java_nio_channels_AsynchronousCloseException;
    _jc_java_nio_channels_ClosedChannelException$sub_refs	java_nio_channels_ClosedChannelException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_channels_ClosedByInterruptException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_channels_ClosedByInterruptException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_nio_channels_ClosedChannelException$sub_nonrefs	java_nio_channels_ClosedChannelException;
    _jc_java_nio_channels_AsynchronousCloseException$sub_nonrefs	java_nio_channels_AsynchronousCloseException;
    _jc_java_nio_channels_ClosedByInterruptException$sub_nonrefs	java_nio_channels_ClosedByInterruptException;
};

// Object instance structure
struct _jc_java_nio_channels_ClosedByInterruptException$object {
	_jc_java_nio_channels_ClosedByInterruptException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_channels_ClosedByInterruptException$vtype	*vtype;
	_jc_java_nio_channels_ClosedByInterruptException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_channels_ClosedByInterruptException$vtype _jc_java_nio_channels_ClosedByInterruptException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_channels_ClosedByInterruptException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_channels_ClosedByInterruptException$class_object;

#endif	/* _JC_java_nio_channels_ClosedByInterruptException_H_ */

==> jc-1.4.6.tar.gz: java/nio/channels/ClosedByInterruptException.h <==
// public class java.nio.channels.ClosedByInterruptException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 3b88087022cf5b94 java_nio_channels_AsynchronousCloseException
// @dep_class 4a6ca7edb3c4d226 java_nio_channels_ClosedByInterruptException
// @dep_class 389bd38d1c277676 java_nio_channels_ClosedChannelException

// header file dependencies
// @dep_header java_nio_channels_AsynchronousCloseException

#include "java/nio/channels/AsynchronousCloseException.h"

#ifndef _JC_java_nio_channels_ClosedByInterruptException_H_
#define _JC_java_nio_channels_ClosedByInterruptException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_nio_channels_ClosedByInterruptException$sub_refs	_jc_java_nio_channels_ClosedByInterruptException$sub_refs;
typedef struct _jc_java_nio_channels_ClosedByInterruptException$sub_nonrefs	_jc_java_nio_channels_ClosedByInterruptException$sub_nonrefs;
typedef struct _jc_java_nio_channels_ClosedByInterruptException$refs	_jc_java_nio_channels_ClosedByInterruptException$refs;
typedef struct _jc_java_nio_channels_ClosedByInterruptException$nonrefs	_jc_java_nio_channels_ClosedByInterruptException$nonrefs;
typedef struct _jc_java_nio_channels_ClosedByInterruptException$object	_jc_java_nio_channels_ClosedByInterruptException$object;

typedef const struct _jc_java_nio_channels_ClosedByInterruptException$vmethods	_jc_java_nio_channels_ClosedByInterruptException$vmethods;
typedef const struct _jc_java_nio_channels_ClosedByInterruptException$vtable	_jc_java_nio_channels_ClosedByInterruptException$vtable;
typedef const struct _jc_java_nio_channels_ClosedByInterruptException$vtype	_jc_java_nio_channels_ClosedByInterruptException$vtype;

// Constructors
extern void _jc_java_nio_channels_ClosedByInterruptException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_channels_ClosedByInterruptException$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_nio_channels_ClosedByInterruptException$vmethods {
};

// Vtable
struct _jc_java_nio_channels_ClosedByInterruptException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_nio_channels_ClosedChannelException$vmethods	java_nio_channels_ClosedChannelException;
	_jc_java_nio_channels_AsynchronousCloseException$vmethods	java_nio_channels_AsynchronousCloseException;
	_jc_java_nio_channels_ClosedByInterruptException$vmethods	java_nio_channels_ClosedByInterruptException;
};

// Vtype
struct _jc_java_nio_channels_ClosedByInterruptException$vtype {
	_jc_type			type;
	_jc_java_nio_channels_ClosedByInterruptException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_channels_ClosedByInterruptException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_channels_ClosedByInterruptException$refs {
    _jc_java_nio_channels_ClosedByInterruptException$sub_refs	java_nio_channels_ClosedByInterruptException;
    _jc_java_nio_channels_AsynchronousCloseException$sub_refs	java_nio_channels_AsynchronousCloseException;
    _jc_java_nio_channels_ClosedChannelException$sub_refs	java_nio_channels_ClosedChannelException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_channels_ClosedByInterruptException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_channels_ClosedByInterruptException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_nio_channels_ClosedChannelException$sub_nonrefs	java_nio_channels_ClosedChannelException;
    _jc_java_nio_channels_AsynchronousCloseException$sub_nonrefs	java_nio_channels_AsynchronousCloseException;
    _jc_java_nio_channels_ClosedByInterruptException$sub_nonrefs	java_nio_channels_ClosedByInterruptException;
};

// Object instance structure
struct _jc_java_nio_channels_ClosedByInterruptException$object {
	_jc_java_nio_channels_ClosedByInterruptException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_channels_ClosedByInterruptException$vtype	*vtype;
	_jc_java_nio_channels_ClosedByInterruptException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_channels_ClosedByInterruptException$vtype _jc_java_nio_channels_ClosedByInterruptException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_channels_ClosedByInterruptException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_channels_ClosedByInterruptException$class_object;

#endif	/* _JC_java_nio_channels_ClosedByInterruptException_H_ */
